@@ -1,4 +1,3 @@
-#!perl
 use 5.008001;
 use utf8;
 use strict;
@@ -8,10 +7,13 @@ use warnings;
 ###########################################################################
 
 # Constant values used by packages in this file:
-use only 'Readonly' => '1.03-';
-Readonly my %TEXT_STRINGS => (
+my $TEXT_STRINGS = {
     # This group of strings is generic and can be used by any package:
 
+    'LKT_ARGS_BAD_PSEUDO_NAMED'
+        => q[<CLASS>.<METH>(): bad pseudo-named arguments list;]
+            . q[ it must have an even number of positional elements.],
+
     'LKT_ARG_UNDEF'
         => q[<CLASS>.<METH>(): argument <ARG> is undefined (or missing).],
     'LKT_ARG_NO_ARY'
@@ -84,23 +86,26 @@ Readonly my %TEXT_STRINGS => (
         => q[<CLASS>.<METH>(): can't invoke get_text_by_key() on]
            . q[ Locale::KeyedText Template module '<TMPL_MOD_NAME>':]
            . q[ <REASON>],
-);
+};
 
 ###########################################################################
 ###########################################################################
 
 { package Locale::KeyedText::L::en; # module
-    use version; our $VERSION = qv('1.0.1');
+    BEGIN {
+        our $VERSION = '2.000000';
+        $VERSION = eval $VERSION;
+    }
     sub get_text_by_key {
         my (undef, $msg_key) = @_;
-        return $TEXT_STRINGS{$msg_key};
+        return $TEXT_STRINGS->{$msg_key};
     }
 } # module Locale::KeyedText::L::en
 
 ###########################################################################
 ###########################################################################
 
-1; # Magic true value required at end of a reuseable file's code.
+1;
 __END__
 
 =pod
@@ -114,7 +119,7 @@ Localization of Locale::KeyedText for English
 
 =head1 VERSION
 
-This document describes Locale::KeyedText::L::en version 1.0.1.
+This document describes Locale::KeyedText::L::en version 2.0.0.
 
 =head1 SYNOPSIS
 
@@ -140,12 +145,6 @@ I<This documentation is pending.>
 
 This file requires any version of Perl 5.x.y that is at least 5.8.1.
 
-It also requires the Perl 5 packages L<version> and L<only>, which would
-conceptually be built-in to Perl, but aren't, so they are on CPAN instead.
-
-It also requires these Perl 5 packages that are on CPAN:
-L<Readonly-(1.03...)|Readonly>.
-
 =head1 INCOMPATIBILITIES
 
 None reported.
@@ -160,15 +159,13 @@ I<This documentation is pending.>
 
 =head1 AUTHOR
 
-Darren R. Duncan (C<perl@DarrenDuncan.net>)
+Darren Duncan (C<darren@DarrenDuncan.net>)
 
-=head1 LICENCE AND COPYRIGHT
+=head1 LICENSE AND COPYRIGHT
 
-This file is part of the Locale::KeyedText library.
+Locale::KeyedText is Copyright © 2003-2016, Muldis Data Systems, Inc.
 
-Locale::KeyedText is Copyright (c) 2003-2006, Darren R. Duncan.
-
-See the LICENCE AND COPYRIGHT of L<Locale::KeyedText> for details.
+See the LICENSE AND COPYRIGHT of L<Locale::KeyedText> for details.
 
 =head1 ACKNOWLEDGEMENTS
 
